/*  
 *  - - - - - - - - - -
 *   g a l _ l d s s r 
 *  - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine loads an object catalog from a US Strategic
 *     Command Satellite Situation Report file.
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *
 *  Given:
 *
 *     *fp              FILE          Pointer to open file
 *
 *
 *  Returned:  
 *  
 *     *objcat      gal_objcat_t      Pointer to object catalog
 *     *status      gal_status_t      Pointer to status structure
 * 
 *  Notes:
 *
 *  1)  The Satellite Situation Report is a listing of those satellites
 *      (objects) currently in orbit and those which have previously 
 *      orbited the Earth. Some objects are too small or too far from 
 *      the Earth's surface to be detected; therefore, the Satellite 
 *      Situation Report does not include all man-made objects orbiting 
 *      the Earth.
 *
 *  2)  The latest report can be downloaded from here:
 *
 *      http://www.space-track.org/perl/login.pl
 *
 *  Called:
 *
 *     gal_stsinit           Initialize status structure
 *     gal_errset            Set error code
 *     gal_stsfree           Free status structure
 *     gal_sseek             Seek for a string in a file     
 *     gal_stsadd            Merge status structures
 *     gal_errc              Get error count
 *     gal_trim              Trim whitespace from string ends
 *     gal_fscan             Decode FORTRAN style string
 *     gal_piece_ins         Add piece of launch to object catalog
 *     gal_instr             Search for substring in string
 *     gal_cal2jd            Calendar date to Julian Date
 *     gal_lvcode            Get launch vehicle code
 *     gal_objowner_code     Get Catalog Object Owner Code
 *     gal_getlaunch         Find launch in object catalog
 *
 *  This revision:  
 * 
 *     2010 February 27 Paul Willmott Baseline
 *  
 *  Revision History:
 *
 *     2010 February 27 Paul Willmott Baseline
 * 
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_LDSSR_H_  
#define _GAL_LDSSR_H_ 1  

#include <stdio.h>
#include "gal_usstratcom.h"
#include "gal_status_t.h"

#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif

__BEGIN_DECLS  

void
gal_ldssr
(
  FILE         *fp,
  gal_objcat_t *objcat,
  gal_status_t *status
) ;  

__END_DECLS  

#endif /* !_GAL_LDSSR_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
