/*  
 *  - - - - - - - - - - - - - - - 
 *   g a l _ l d s s r _ t e s t  
 *  - - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     Test gal_ldssr, gal_objcat_export & gal_objcat_import routines.  
 *  
 *  Status:  
 *  
 *     Internal test routine  
 *  
 *  Called:
 *  
 *     gal_ldssr                       Load Satellite Situation Report
 *     gal_objcat_export               Export object catalog
 *     gal_objcat_import               Import object catalog
 *     gal_vdv                         Verify double value
 *     gal_viv                         Verify integer value
 *     gal_vsv                         Verify string value
 *     gal_stsalloc                    Create status structure
 *     gal_stsfree                     Free status structure
 *     gal_objcat_alloc                Create object catalog instance
 *     gal_objcat_free                 Free object catalog
 *  
 *  This revision:
 *
 *     2010 March 25 Paul Willmott Updated for gal_objcat_import.
 *
 *  Revision History:
 *
 *     2010 February 28 Paul Willmott Baseline
 *
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  

#include <unistd.h>
#include <stdio.h>  
#include <string.h>
#include "gal_ldssr_test.h"
#include "gal_ldssr.h"
#include "gal_test.h"
#include "gal_status.h"
#include "gal_objcat_alloc.h"
#include "gal_objcat_free.h"
#include "gal_objcat_export.h"
#include "gal_objcat_import.h"
  
void  
gal_ldssr_test  
(  
) 

{

  extern int gal_tfunc ;
  
  FILE *fp ;
  
  gal_status_t *status ;
  
  gal_objcat_t *objcat, *objcat2 ;
  
  gal_launch_t *launch, *launch2 ;
  
  gal_piece_t *piece, *piece2 ;
  
  char cwd[1024], path[1024] ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */

  status = gal_stsalloc () ;
  
  objcat  = gal_objcat_alloc () ;
  objcat2 = gal_objcat_alloc () ;

/*
 * Load Satellite Situation Report
 */
 
  getcwd ( cwd, sizeof ( cwd ) ) ;
  strcpy ( path, cwd ) ;
  strcat ( path, "/test_data/ssr_20100222.txt" ) ;
  fp = fopen ( path, "r" ) ;
  gal_ldssr ( fp, objcat, status ) ;
  fclose ( fp ) ;

/*
 * Write GAL Object Catalog to file
 */
 
  strcpy ( path, cwd ) ;
  strcat ( path, "/objcat.txt" ) ;
  
  fp = fopen ( path, "w" ) ;
  gal_objcat_export ( fp, objcat, GAL_SAVEALL, status ) ;
  fclose ( fp ) ;
  
  fp = fopen ( path, "r" ) ;
  gal_objcat_import ( fp, objcat2, status ) ;
  fclose ( fp ) ;

  launch = objcat->launch ;
  launch2 = objcat2->launch ;
  while ( launch != NULL && launch2 != NULL ) {
  
    piece  = launch->piece ;
    piece2 = launch2->piece ;
        
    while ( piece != NULL && piece2 != NULL ) {
    
      gal_vsv ( piece2->piece,        piece->piece,           "gal_objcat_import", "piece"        ) ;
      gal_viv ( piece2->satnum,       piece->satnum,          "gal_objcat_import", "satnum"       ) ;
      gal_vsv ( piece2->intldesg,     piece->intldesg,        "gal_objcat_import", "intldesg"     ) ;
      gal_vsv ( piece2->name,         piece->name,            "gal_objcat_import", "name"         ) ;
      gal_vdv ( piece2->launch_date1, piece->launch_date1, 0, "gal_objcat_import", "launch_date1" ) ;
      gal_vdv ( piece2->launch_date2, piece->launch_date2, 0, "gal_objcat_import", "launch_date2" ) ;
      gal_viv ( piece2->status,       piece->status,          "gal_objcat_import", "status"       ) ;
      gal_vdv ( piece2->decay_date1,  piece->decay_date1,  0, "gal_objcat_import", "decay_date1"  ) ;
      gal_vdv ( piece2->decay_date2,  piece->decay_date2,  0, "gal_objcat_import", "decay_date2"  ) ;
      gal_vdv ( piece2->period,       piece->period,       0, "gal_objcat_import", "period"       ) ;
      gal_vdv ( piece2->inclo,        piece->inclo,        0, "gal_objcat_import", "inclo"        ) ;
      gal_vdv ( piece2->apogee,       piece->apogee,       0, "gal_objcat_import", "apogee"       ) ;
      gal_vdv ( piece2->perigee,      piece->perigee,      0, "gal_objcat_import", "perigee"      ) ;
      gal_vdv ( piece2->rcs,          piece->rcs,          0, "gal_objcat_import", "rcs"          ) ;
      gal_viv ( piece2->owner_code,   piece->owner_code,      "gal_objcat_import", "owner_code"   ) ;
      gal_viv ( piece2->payload,      piece->payload,         "gal_objcat_import", "payload"      ) ;
      
      piece  = piece->next ;
      piece2 = piece2->next ;
      
    }
    
    launch  = launch->next ;
    launch2 = launch2->next ;
    
  }

  gal_objcat_free ( objcat2 ) ;
  gal_objcat_free ( objcat ) ;
  
  gal_stsfree ( status ) ;

  gal_tfunc++ ;
  
/*  
 * Finished.  
 */  

}

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
