/*  
 *  - - - - - - - - - - - - - - - 
 *   g a l _ l d t l e _ t e s t  
 *  - - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     Test gal_ldtle, and gal_svtle routines.  
 *  
 *  Status:  
 *  
 *     Internal test routine  
 *  
 *  Called:
 *  
 *     gal_ldtle                       Load TLEs
 *     gal_vdv                         Verify double value
 *     gal_stsalloc                    Create status structure
 *     gal_stsfree                     Free status structure
 *     gal_viv                         Verify integer value
 *     gal_vsv                         Verify string value
 *     gal_svtle                       Save TLEs
 *     gal_objcat_alloc                Create object catalog instance
 *  
 *  This revision:
 *
 *     2010 March 20 Paul Willmott Baseline
 *
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include "gal_ldtle_test.h"
#include "gal_ldtle.h"
#include "gal_test.h"
#include "gal_usstratcom.h"
#include "gal_status.h"
#include "gal_svtle.h"
  
void  
gal_ldtle_test  
(  
) 

{


  extern int gal_tfunc ;
  
  FILE *fp ;
  
  gal_status_t *status ;
  
  gal_objcat_t *objcat ;
  
  gal_launch_t *launch ;
  
  gal_piece_t *piece ;
  
  int inorbit = 0, payloads = 0, debris = 0 ;
  
  char cwd[1024], path[1024] ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */

  status = gal_stsalloc () ;
  
  objcat = gal_objcat_alloc () ;

/*
 * Load Satellite Situation Report
 */
 
  getcwd ( cwd, sizeof ( cwd ) ) ;
  strcpy ( path, cwd ) ;
  strcat ( path, "/test_data/catalog_3l_2010_03_13_am.txt" ) ;
  fp = fopen ( path, "r" ) ;
  gal_ldtle ( fp, GAL_LOADALL, objcat, status ) ;
  fclose ( fp ) ;

/*
 * Write TLEs to file
 */
 
  strcpy ( path, cwd ) ;
  strcat ( path, "/tle.txt" ) ;
  fp = fopen ( path, "w" ) ;
  gal_svtle ( fp, objcat, 1, GAL_SAVEALL, status ) ;
  fclose ( fp ) ; 
 
  launch = objcat->launch ;
  while ( launch != NULL ) {
  
    piece = launch->piece ;
        
    while ( piece != NULL ) {
    
      if ( piece->status == GAL_COS_GEOCENTRIC_ORBIT ) {
        inorbit++ ;
        if ( piece->payload == 1 ) {
          payloads++ ;
        }
        else {
          debris++ ;
        }
      }
    
      piece = piece->next ;
      
    }
    
    launch = launch->next ;
    
  }

  gal_viv ( payloads != 0, 1, "gal_ldtle", "payloads" ) ;
  gal_viv ( debris   != 0, 1, "gal_ldtle", "debris" ) ;
  gal_viv ( inorbit  != 0, 1, "gal_ldtle", "inorbit" ) ;
    
  gal_objcat_free ( objcat ) ;
  
  gal_stsfree ( status ) ;

  gal_tfunc++ ;
  
/*  
 * Finished.  
 */  

}
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
