/*  
 *  - - - - - - - - - - - 
 *   g a l _ l v c o d e
 *  - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine returns the code of a launch vehicle.
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *  Given:
 *
 *     *name              c[]         Pointer to name string
 *  
 *  Returned:  
 *  
 *     *gal_lvcode         i          Launcher code
 * 
 *  Notes:
 *
 *  1) The header file "gal_tle.h" defines the applicable GAL_LV_* constants.
 *
 *  2) If the specified launcher name is not known to the routine then
 *     the the routine returns GAL_LV_UNKNOWN.
 * 
 *  Called:
 *
 *    gal_errc                        Get error count
 *    gal_lvname                      Get launcher name
 *    gal_replace                     Replace sub-string with string
 *    gal_instr                       Find sub-string in string
 *    gal_stsalloc                    Create status structure
 *    gal_stsfree                     Free status structure
 *    gal_padr                        Pad string on right with spaces
 *
 *  This revision:  
 * 
 *     2010 March 7 Paul Willmott Baseline
 *  
 *  Revision History:
 *
 *     2010 March 7 Paul Willmott Baseline
 * 
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_LVCODE_H_  
#define _GAL_LVCODE_H_ 1  

#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif

__BEGIN_DECLS  

int
gal_lvcode
(
  char *name
) ;  

__END_DECLS  

#endif /* !_GAL_LVCODE_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
