/*  
 *  - - - - - - - - - - - - - - - - - -
 *   g a l _ o b j c a t _ e x p o r t
 *  - - - - - - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine exports the contents of an object catalog 
 *     structure to a fixed format ASCII file.
 *  
 *  Status: 
 *  
 *     support routine. 
 *
 *  Given:
 *
 *     *fp              FILE          Pointer to open file pointer
 *     *objcat      gal_objcat_t      Pointer to object catalog structure 
 *     options           i            Export options ( see Note 1 )
 *  
 *  Returned:  
 *
 *     *status      gal_status_t      Pointer to status structure  
 * 
 *  Notes:
 *
 *  1) If OPTIONS is set to GAL_SAVEALL then all pieces of launch
 *     are exported. If OPTIONS is set to GAL_SAVETAGGED then only 
 *     those pieces of launch which are tagged (i.e. non-zero value 
 *     for TAG) are exported.
 *
 *  This revision:  
 * 
 *     2010 March 25 Paul Willmott Export options added.
 *  
 *  Revision History:
 *
 *     2010 March 7 Paul Willmott Baseline
 * 
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_OBJCAT_EXPORT_H_  
#define _GAL_OBJCAT_EXPORT_H_ 1  

#include "gal_status_t.h"
#include "gal_usstratcom.h"

#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif

__BEGIN_DECLS  

void
gal_objcat_export
(
  FILE *fp,
  gal_objcat_t *objcat,
  int options,
  gal_status_t *status
) ;  

__END_DECLS  

#endif /* !_GAL_OBJCAT_EXPORT_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
