/*  
 *  - - - - - - - - - - - - - - - - - -
 *   g a l _ o b j c a t _ i m p o r t
 *  - - - - - - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine loads the contents of a GAL OBJCAT export file
 *     into an object catalog structure.
 *  
 *  Status: 
 *  
 *     support routine. 
 *
 *  Given:
 *
 *     *fp              FILE          Pointer to open file pointer
 *  
 *  Returned:  
 *
 *     *objcat      gal_objcat_t      Pointer to object catalog structure 
 *     *status      gal_status_t      Pointer to status structure  
 * 
 *  Notes:
 *
 *  1) The routine will first empty the object catalog before
 *     populating from the ASCII file.
 *
 *  2) This routine assumes that the file was created by gal_objcat_export.
 *     If the user has manually updated the ASCII file then the functionality
 *     of this routine cannot be guarented.
 * 
 *  Called:
 *
 *     gal_objcat_init                Initialize object catalog
 *     gal_stsinit                    Initialize status structure
 *     gal_stsalloc                   Create status structure
 *     gal_stsfree                    Free status structure
 *     gal_errset                     Set error code
 *     gal_trimr                      Trim white space from right of string
 *     gal_fscan                      Decode FORTRAN record
 *     gal_piece_ins                  Insert piece of launch into object catalog
 *     gal_getlaunch                  Get launch
 *     gal_stsadd                     Merge status structures
 *
 *  This revision:  
 * 
 *     2014 February 4 Paul Willmott Fixed unitialized LAUNCH variable.
 *  
 *  Revision History:
 *
 *     2010 March 25 Paul Willmott Baseline.
 * 
 *  Copyright (C) 2010-2014 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_OBJCAT_IMPORT_H_  
#define _GAL_OBJCAT_IMPORT_H_ 1  

#include "gal_status_t.h"
#include "gal_usstratcom.h"

#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif

__BEGIN_DECLS  

void
gal_objcat_import
(
  FILE *fp,
  gal_objcat_t *objcat,
  gal_status_t *status
) ;  

__END_DECLS  

#endif /* !_GAL_OBJCAT_IMPORT_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010-2014 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
