/*  
 *  - - - - - - - - - - - - - - - -
 *   g a l _ o b j c a t _ i n d e x
 *  - - - - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine creates an index for an object catalog structure.
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *  Given:  
 *
 *     *objcat      gal_objcat_t      Pointer to object catalog structure
 * 
 *  Returned:
 *
 *     *status      gal_status_t      Pointer to status structure
 * 
 *  This revision:  
 * 
 *     2010 March 21 Paul Willmott Baseline
 *  
 *  Revision History:
 *
 *     2010 March 21 Paul Willmott Baseline
 * 
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <stdlib.h>
#include "gal_usstratcom.h"
#include "gal_objcat_index.h"
#include "gal_status.h"

void
gal_objcat_index
(
  gal_objcat_t *objcat,
  gal_status_t *status 
) 

{

  gal_launch_t *launch ;
  
  gal_piece_t *piece ;
  
  int i ;
      
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  gal_stsinit ( status ) ;
    
/*
 * Check for valid object catalog pointer
 */
 
  if ( objcat == NULL ) {
    gal_errset ( __FILE__, __LINE__, GAL_NULL_POINTER, status ) ;
    return ;
  }
  
/*
 * Dispose of any existing index
 */
 
  if ( objcat->index != NULL ) {
    free ( objcat->index ) ;
    objcat->index = NULL ;
  }
  
/*
 * Create index based upon the largest USSTRATCOM Object Number
 * inserted into the object catalog.
 */
 
 objcat->index = ( gal_piece_t ** ) malloc ( ( objcat->maxsatnum ) * sizeof ( gal_piece_t * ) ) ;
 
/*
 * Clear the index
 */
 
 for ( i = 0; i < objcat->maxsatnum; i++ ) {
   objcat->index[i] = NULL ;
 }

/*
 * Process all launches
 */
 
  launch = objcat->launch ;
  
  while ( launch != NULL ) {
  
/*
 * Process all pieces of launch
 */
 
    piece = launch->piece ;
    
    while ( piece != NULL ) {
    
      objcat->index[piece->satnum-1] = piece ;
    
      piece = piece->next ;
      
    }
  
    launch = launch->next ;
    
  }
  
/*  
 * Finished.  
 */  

}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
