/*  
 *  - - - - - - - - - - - - - - - -
 *   g a l _ o b j c a t _ i n i t
 *  - - - - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine initializes an object catalog structure.
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *  Given:  
 *
 *     *objcat      gal_objcat_t      Pointer to object catalog structure
 *  
 *  This revision:  
 * 
 *     2010 February 27 Paul Willmott Baseline
 *  
 *  Revision History:
 *
 *     2010 February 27 Paul Willmott Baseline
 * 
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <stdlib.h>
#include "gal_objcat_init.h"

void
gal_objcat_init
(
  gal_objcat_t *objcat 
) 

{

  gal_launch_t *lptr, *llptr ;
  gal_piece_t  *pptr, *lpptr ;
  gal_tle_t    *tptr, *ltptr ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
/*
 * Only initialize valid pointers
 */
  
  if ( objcat == NULL ) {
    return ;
  }
  
/*
 * Clear Index if allocated
 */
 
  if ( objcat->index != NULL ) {
    free ( objcat->index ) ;
    objcat->index = NULL ;
  }
  objcat->maxsatnum = 0 ;
  
/*
 * Process all launches
 */
  
  lptr = objcat->launch ;
  
  while ( lptr != NULL ) {
  
/*
 * Process all pieces of launch
 */
 
    pptr = lptr->piece ;
    
    while ( pptr != NULL ) {
    
/*
 * Process all tles
 */
 
      tptr = pptr->tle ;
      
      while ( tptr != NULL ) {

/*
 * Free TLE node, and move to next node
 */

        ltptr = tptr ;
        tptr = tptr->next ;
        free ( ltptr ) ;
      
      }
      
      pptr->tle = NULL ;
      pptr->tcount = 0 ;
    
/*
 * Free piece node, and move to next node
 */
      lpptr = pptr ;
      pptr = pptr->next ;
      free ( lpptr ) ;
 
    }
    
    lptr->piece = NULL ;
    lptr->pcount = 0 ;
  
/*
 * Free launch node, and move to next node
 */
 
    llptr = lptr ;
    lptr = lptr->next ;
    free ( llptr ) ;
    
  }
  
  objcat->launch = NULL ;
  
/*  
 * Finished.  
 */  
  
}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
