/*  
 *  - - - - - - - - - - - - - - - - - -
 *   g a l _ o b j o w n e r _ c o d e 
 *  - - - - - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine returns the code of a catalog object's owner
 *     organization or country for the specified US Space Command
 *     abbreviation code.
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *  Given:
 *
 *     *owner                  c[]        US Space Command Owner identifier code
 *  
 *  Returned:  
 *  
 *     gal_objowner_name        i         GAL Catalog Object Owner Code
 * 
 *  Notes:
 *
 *  1) The header file "gal_tle.h" defines the applicable GAL_COO_* constants.
 *
 *  2) If the specified identifier code is not known to the routine then
 *     the error code then the routine returns GAL_COO_UNKNOWN.
 * 
 *  Called:
 *
 *     gal_stsinit                    Initialize status structure
 *     gal_errset                     Set error code
 *
 *  This revision:  
 * 
 *     2010 March 7 Paul Willmott Baseline
 *  
 *  Revision History:
 *
 *     2010 March 7 Paul Willmott Baseline
 * 
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_OBJOWNER_CODE_H_  
#define _GAL_OBJOWNER_CODE_H_ 1  

#include "gal_status_t.h"

#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif

__BEGIN_DECLS  

int
gal_objowner_code
(
  char *owner
) ;  

__END_DECLS  

#endif /* !_GAL_OBJOWNER_CODE_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
