/*  
 *  - - - - - - - - - - - - - - - - - -  
 *   g a l _ o b j o w n e r _ n a m e
 *  - - - - - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine returns the name of a Catalog Object's Owner.
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *  Given:
 *
 *     owner                     i          Catalog object owner identifier code
 *  
 *  Returned:  
 *  
 *     *name                    c[]         Pointer to name string
 *     *status              gal_status_t    Pointer to status structure
 *     *gal_objowner_name       c[]         Pointer to name string, NULL if failure
 * 
 *  Notes:
 *
 *  1) The header file "gal_tle.h" defines the applicable GAL_COO_* constants.
 *
 *  2) If the specified identifier code is not known to the routine then
 *     the error code GAL_INVALID_ID is set, and the routine returns NULL.
 * 
 *  Called:
 *
 *     gal_stsinit                    Initialize status structure
 *     gal_errset                     Set error code
 *
 *  This revision:  
 * 
 *     2010 March 7 Paul Willmott Baseline
 *  
 *  Revision History:
 *
 *     2010 March 7 Paul Willmott Baseline
 * 
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <string.h>
#include "gal_usstratcom.h"
#include "gal_objowner_name.h"
#include "gal_status.h"

char *
gal_objowner_name
(
  int owner,
  char *name,
  gal_status_t *status
) 

{

  char *owner_names[GAL_MAX_OWNERS] = {
  
    "UNKNOWN               ", 
    "ALGERIA               ",
    "ARABSAT               ",
    "ARGENTINA             ",
    "ASIASAT CORPORATION   ",
    "AUSTRALIA             ",
    "BERMUDA               ",
    "BRAZIL                ",
    "CANADA                ",
    "CHILE                 ",
    "CIS                   ",
    "COLUMBIA              ",
    "CZECHOSLOVAKIA        ",
    "DENMARK               ",
    "EGYPT                 ",
    "ESA                   ",
    "ESRO                  ",
    "EUMETSAT              ",
    "EUTELSAT              ",
    "FRANCE                ",
    "FRANCE/GERMANY        ",
    "GERMANY               ",
    "GLOBALSTAR            ",
    "GREECE                ",
    "INDIA                 ",
    "INDONESIA             ",
    "INMARSAT              ",
    "INTELSAT              ",
    "IRAN                  ",
    "IRIDIUM               ",
    "ISRAEL                ",
    "ISRO                  ",
    "ISS                   ",
    "ITALY                 ",
    "JAPAN                 ",
    "KOREA                 ",
    "LUXEMBOURG            ",
    "MALAYSIA              ",
    "MEXICO                ",
    "NATO                  ",
    "NETHERLANDS           ",
    "NEW ICO               ",
    "NIGERIA               ",
    "NORTH_KOREA           ",
    "NORWAY                ",
    "PAKISTAN              ",
    "PHILIPPINES           ",
    "PORTUGAL              ",
    "PRC                   ",
    "PRC/BRAZIL            ",
    "PRC/ESA               ",
    "RASC                  ",
    "SAUDI ARABIA          ",
    "SEA LAUNCH            ",
    "SINGPORE/TAIWAN       ",
    "SOUTH AFRICA          ",
    "SOUTH KOREA           ",
    "SPAIN                 ",
    "SWEDEN                ",
    "SWITZERLAND           ",
    "TAIWAN                ",
    "THAILAND              ",
    "TURKEY                ",
    "UNITED ARAB EMIRATES  ",
    "UNITED KINGDOM        ",
    "USA                   ",
    "USA/BRAZIL            ",
    "VENEZUELA             ",
    "VIETNAM               "
  } ;

/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  gal_stsinit ( status ) ;
  
  if ( owner < 0 || owner >= GAL_MAX_OWNERS ) {
    gal_errset ( __FILE__, __LINE__, GAL_INVALID_ID, status ) ;
    return NULL ;
  }
  
  strcpy ( name, owner_names[owner] ) ;
  
  return name ;
  
/*  
 * Finished.  
 */ 

}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
