/*  
 *  - - - - - - - - - - - - - - - -  
 *   g a l _ s g p 4 r s _ t e s t  
 *  - - - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     Test gal_sgp4rs routine.  
 *  
 *  Status:  
 *  
 *     Internal test routine  
 *  
 *  Called:
 *  
 *     gal_sgp4rs                    Rise/Set routine
 *     gal_vdv                       Verify double value
 *     gal_tledec                    Decode TLEs
 *     gal_cal2jd                    Calendar to Julian Date
 *     gal_sgp4init                  Initialize SGP4 structure
 *     gal_stsalloc                  Create status structure
 *     gal_stsfree                   Free status structure
 *     gal_gmget_wgs72               Get copy of WGS72 gravity model
 *     gal_gmfree                    Free gravity model
 *  
 *  This revision:
 *  
 *     2010 February 14 Paul Willmott Changed to use gal_gmget_wgs72 routine.
 *
 *  Revision History:
 *
 *     2010 February 7 Paul Willmott Changed to use GAL status recording
 *                                   mechanism.
 *
 *     2010 January 10 Paul Willmott Typo in #include <string.h> corrected
 *                                   Missing #include "gal_tledec.h" added
 *                                   "Called" comments updated.
 *
 *     2009 January 9 Paul Willmott Baseline
 * 
 *  Copyright (C) 2009, 2010, 2011, 2012 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  

#include <string.h>  
#include "gal_sgp4rs_test.h"
#include "gal_sgp4rs.h"
#include "gal_sgp4.h"
#include "gal_test.h"
#include "gal_cal2jd.h"
#include "gal_tledec.h"
#include "gal_status.h"
#include "gal_math_macros.h"
#include "gal_gmget_wgs72.h"
#include "gal_gmfree.h"

void  
gal_sgp4rs_test  
(  
) 
 
{

  extern int gal_tfunc ; 
  
  char card1[70], card2[70] ;

  gal_tle_t tle ;
  
  gal_sgp4_t sgp4 ;

  double pass[3][3], jd1, jd2 ;
  
  gal_gm_t *gmwgs72 ;
  
  gal_status_t *status ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  status = gal_stsalloc () ;
  
  gmwgs72 = gal_gmget_wgs72 ( 28, 27, 1, status ) ;
  
/* MIR (Decayed 2001-03-23) */
  
  strcpy ( card1, "1 16609U 86017A   98179.12855085  .00011228  00000-0  11636-3 0  5947" ) ;  
  strcpy ( card2, "2 16609 051.6594 351.2391 0007677 156.4214 203.7122 15.65212417705775" ) ;  

  gal_tledec ( card1, card2, &tle, status ) ; 

  gal_sgp4init ( gmwgs72, &tle, &sgp4, status ) ;  

  gal_sgp4rs ( 2450994.0, 0.0, 40.76978 * GAL_D2R, -73.79533 * GAL_D2R, 27.0, 0.0 * GAL_D2R, 2.0, gmwgs72->gm, gmwgs72->sma, 1.0 / 298.26, &sgp4, pass, status ) ;

/* 6/29/98 12:59:13 */
  gal_cal2jd ( 1998, 6, 29, &jd1, &jd2, status ) ;
  jd2 += 12.0 / 24.0 + 59.0 / 1440.0 + 13.0 / 86400.0 ;
  
  gal_vdv ( pass[0][0],           jd1+jd2, 1e-5, "gal_sgp4rs", "AOS Time 0") ;  
  gal_vdv ( pass[0][1] * GAL_R2D, -3.73168857385053E-03, 1e-2, "gal_sgp4rs", "AOS Elev 0") ;  
  gal_vdv ( pass[0][2] * GAL_R2D, 255.9993374263, 1e-1, "gal_sgp4rs", "AOS Azim 0") ;  

/* 6/29/98 13:04:11 */
  gal_cal2jd ( 1998, 6, 29, &jd1, &jd2, status ) ;
  jd2 += 13.0 / 24.0 + 4.0 / 1440.0 + 11.0 / 86400.0 ;
  gal_vdv ( pass[1][0],           jd1+jd2, 1e-5, "gal_sgp4rs", "CUL Time 0") ;  
  gal_vdv ( pass[1][1] * GAL_R2D, 30.7873819444898, 1e-1, "gal_sgp4rs", "CUL Elev 0") ;  
  gal_vdv ( pass[1][2] * GAL_R2D, 332.192815750249, 1e-1, "gal_sgp4rs", "CUL Azim 0") ;  

/* 6/29/98 13:09:09 */
  gal_cal2jd ( 1998, 6, 29, &jd1, &jd2, status ) ;
  jd2 += 13.0 / 24.0 + 9.0 / 1440.0 + 9.0 / 86400.0 ;
  gal_vdv ( pass[2][0],           jd1+jd2, 1e-5, "gal_sgp4rs", "LOS Time 0") ;  
  gal_vdv ( pass[2][1] * GAL_R2D, 8.92199866986428E-03, 1e-1, "gal_sgp4rs", "LOS Elev 0") ;  
  gal_vdv ( pass[2][2] * GAL_R2D, 48.664528862284, 1e-1, "gal_sgp4rs", "LOS Azim 0") ;  

  gal_sgp4rs ( 2450994.04871648, 0.0, 40.76978 * GAL_D2R, -73.79533 * GAL_D2R, 27.0, 0.0 * GAL_D2R, 2.0, gmwgs72->gm, gmwgs72->sma, 1.0 / 298.26, &sgp4, pass, status ) ;

/* 6/29/98 14:36:20 */
  gal_cal2jd ( 1998, 6, 29, &jd1, &jd2, status ) ;
  jd2 += 14.0 / 24.0 + 36.0 / 1440.0 + 20.0 / 86400.0 ;
  
  gal_vdv ( pass[0][0],           jd1+jd2, 1e-5, "gal_sgp4rs", "AOS Time 1") ;  
  gal_vdv ( pass[0][1] * GAL_R2D, 7.62993160963896E-04, 1e-2, "gal_sgp4rs", "AOS Elev 1") ;  
  gal_vdv ( pass[0][2] * GAL_R2D, 292.974167515014, 1e-1, "gal_sgp4rs", "AOS Azim 1") ;  

/* 6/29/98 14:40:41 */
  gal_cal2jd ( 1998, 6, 29, &jd1, &jd2, status ) ;
  jd2 += 14.0 / 24.0 + 40.0 / 1440.0 + 41.0 / 86400.0 ;
  gal_vdv ( pass[1][0],           jd1+jd2, 1e-5, "gal_sgp4rs", "CUL Time 1") ;  
  gal_vdv ( pass[1][1] * GAL_R2D, 12.0733670587433, 1e-1, "gal_sgp4rs", "CUL Elev 1") ;  
  gal_vdv ( pass[1][2] * GAL_R2D, 351.668492660781, 1e-1, "gal_sgp4rs", "CUL Azim 1") ;  

/* 6/29/98 14:45:02 */
  gal_cal2jd ( 1998, 6, 29, &jd1, &jd2, status ) ;
  jd2 += 14.0 / 24.0 + 45.0 / 1440.0 + 2.0 / 86400.0 ;
  gal_vdv ( pass[2][0],           jd1+jd2, 1e-5, "gal_sgp4rs", "LOS Time 1") ;  
  gal_vdv ( pass[2][1] * GAL_R2D, 5.5793871517464E-05, 1e-1, "gal_sgp4rs", "LOS Elev 1") ;  
  gal_vdv ( pass[2][2] * GAL_R2D, 50.4246519690459, 1e-1, "gal_sgp4rs", "LOS Azim 1") ;  

  gal_gmfree ( gmwgs72 ) ;
  
  gal_stsfree ( status ) ;
  
  gal_tfunc++ ;
  
/*  
 * Finished.  
 */  

}

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2009, 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
