/*  
 *  - - - - - - - - - - 
 *   g a l _ s v t l e
 *  - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine saves the TLEs stored in an object catalog 
 *     structure to a fixed format ASCII file.
 *  
 *  Status: 
 *  
 *     support routine. 
 *
 *  Given:
 *
 *     *fp              FILE          Pointer to open file pointer
 *     *objcat      gal_objcat_t      Pointer to object catalog structure 
 *     style             i            Output file stye
 *     options           i            Save options
 *  
 *  Returned:  
 *
 *     *status      gal_status_t      Pointer to status structure  
 * 
 *  Notes:
 *
 *  1) If OPTIONS is set to GAL_SAVEALL then all TLEs are exported.
 *     If OPTIONS is set to GAL_SAVETAGGED then only TLEs for tagged
 *     (i.e. non-zero value for TAG) pieces of launch are exported.
 *
 *  2) For three line files set STYLE to 1, for two line files set
 *     STYLE to 0. Three line files have the piece of launch name
 *     on the first line followed by two lines containing the cards.
 *     Two line files only have the cards.
 * 
 *  Called:
 *
 *     gal_stsalloc                  Create status structure
 *     gal_errset                    Set error code
 *     gal_stsfree                   Free status structure
 *     gal_stsadd                    Merge status structures
 *     gal_tleenc                    Encode TLE cards
 *
 *  This revision:  
 * 
 *     2010 March 20 Paul Willmott Baseline
 *  
 *  Revision History:
 *
 *     2010 March 20 Paul Willmott Baseline
 * 
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_SVTLE_H_  
#define _GAL_SVTLE_H_ 1  

#include "gal_status_t.h"
#include "gal_usstratcom.h"

#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif

__BEGIN_DECLS  

void
gal_svtle
(
  FILE *fp,
  gal_objcat_t *objcat,
  int style,
  int options,
  gal_status_t *status
) ;  

__END_DECLS  

#endif /* !_GAL_SVTLE_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
