/*  
 *  - - - - - - - - - - - - - - - -  
 *   g a l _ t l e d e c _ t e s t  
 *  - - - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     Test gal_tledec, and gal_tleenc routines.  
 *  
 *  Status:  
 *  
 *     Internal test routine  
 *  
 *  Called:
 *  
 *     gal_tledec                 Decode TLE cards
 *     gal_tleenc                 Encode TLE cards
 *     gal_vdv                    Verify double value
 *     gal_viv                    Verify integer value
 *     gal_vcv                    Verify character value
 *     gal_vsv                    Verify string value
 *     gal_stsalloc               Create status structure
 *     gal_stsfree                Free status structure
 *  
 *  This revision:
 *  
 *     2010 March 20 Paul Willmott Tests for gal_tleenc added.
 * 
 *  Revision History:
 *
 *     2010 January 10 Paul Willmott Typo in #include <string.h> corrected.
 * 
 *     2008 March 30 Paul Willmott Baseline
 * 
 *  Copyright (C) 2008, 2009, 2010, 2011, 2012 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#include <string.h>
#include "gal_tledec_test.h"
#include "gal_tledec.h"
#include "gal_test.h"
#include "gal_status.h"
#include "gal_tleenc.h"
  
void  
gal_tledec_test  
(  
)   

{

  extern int gal_tfunc ; 
  
  char card1[70], card2[70], c1[70], c2[70] ;
  
  gal_tle_t tle ;
  
  gal_status_t *status ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  status = gal_stsalloc () ;

  strcpy ( card1, "1 36096U 09063B   10071.88510990  .00686272  54284-5  60295-3 0  1706" ) ;
  strcpy ( card2, "2 36096 067.1290 228.6714 0244271 343.6145 015.7165 15.73818025 17189" ) ;
  
  gal_tledec ( card1, card2, &tle, status ) ;

  gal_tleenc ( &tle, c1, c2, status ) ;
  gal_vsv ( c1, "1 36096U 09063B   10071.88510990  .00686272  54284-5  60295-3 0  1706", "gal_tleenc", "card1 0" ) ;  
  gal_vsv ( c2, "2 36096  67.1290 228.6714 0244271 343.6145  15.7165 15.73818025 17189", "gal_tleenc", "card2 0" ) ;  
  
  strcpy ( card1, "1 25107U 97082D   98151.26839894 -.00007632  00000-0 -27359-2 0  1321" ) ;
  strcpy ( card2, "2 25107  86.3970 282.3520 0003565  65.4476 294.7132 14.34205441 23251" ) ;

  gal_tledec ( card1, card2, &tle, status ) ;

  gal_tleenc ( &tle, c1, c2, status ) ;
  gal_vsv ( c1, "1 25107U 97082D   98151.26839894 -.00007632  00000-0 -27359-2 0  1321", "gal_tleenc", "card1 1" ) ;  
  gal_vsv ( c2, "2 25107  86.3970 282.3520 0003565  65.4476 294.7132 14.34205441 23251", "gal_tleenc", "card2 1" ) ;  
      
  gal_viv ( gal_errc ( status ) , 0, "gal_tledec", "status 0" ) ;  
      
  gal_viv ( tle.satnum,         25107,             "gal_tledec", "satnum 0"         ) ;  
  gal_vcv ( tle.classification, 'U',               "gal_tledec", "classification 0" ) ;  
  gal_vsv ( tle.intldesg,       "1997-082D  ",     "gal_tledec", "intldesg 0"       ) ;  
  gal_viv ( tle.epochyr,        1998,              "gal_tledec", "epochyr 0"        ) ;  
  gal_vdv ( tle.epochdays,      151.26839894, 0.0, "gal_tledec", "epochdays 0"      ) ;  
  gal_vdv ( tle.ndot,           -0.00007632,  0.0, "gal_tledec", "ndot 0"           ) ;  
  gal_vdv ( tle.nddot,          -0.00000e0,   0.0, "gal_tledec", "nddot 0"          ) ;  
  gal_vdv ( tle.bstar,          -0.27359e-2,  0.0, "gal_tledec", "bstar 0"          ) ;  
  gal_viv ( tle.ephtype,        0,                 "gal_tledec", "ephtype 0"        ) ;  
  gal_viv ( tle.setnum,         132,               "gal_tledec", "setnum 0"         ) ;  
  gal_vdv ( tle.inclo,          86.3970,      0.0, "gal_tledec", "inclo 0"          ) ;  
  gal_vdv ( tle.nodeo,          282.3520,     0.0, "gal_tledec", "nodeo 0"          ) ;  
  gal_vdv ( tle.ecco,           0.0003565,    0.0, "gal_tledec", "ecco 0"           ) ;  
  gal_vdv ( tle.argpo,          65.4476,      0.0, "gal_tledec", "argpo 0"          ) ;  
  gal_vdv ( tle.mo,             294.7132,     0.0, "gal_tledec", "mo 0"             ) ;  
  gal_vdv ( tle.no,             14.34205441,  0.0, "gal_tledec", "no 0"             ) ;  
  gal_viv ( tle.revnum,         2325,              "gal_tledec", "revnum 0"         ) ;  

  gal_tfunc++ ;  

  strcpy ( card1, "1 25107U 97082D   98151.26839894 -.00007632  00000-0 -27359-2 0  1322" ) ;
  strcpy ( card2, "2 25107  86.3970 282.3520 0003565  65.4476 294.7132 14.34205441 23252" ) ;

  gal_tledec ( card1, card2, &tle, status ) ;
  
  gal_viv ( gal_errc ( status ), 1, "gal_tledec", "status 1" ) ;  
  
  strcpy ( card1, "1 25107U 97082D   98151.26839894 -.00007632  00000-0 -27359-2 0  132" ) ;
  strcpy ( card2, "2 25107  86.3970 282.3520 0003565  65.4476 294.7132 14.34205441 2325" ) ;

  gal_tledec ( card1, card2, &tle, status ) ;
  
  gal_viv ( gal_errc ( status ), 1, "gal_tledec", "status 2" ) ;  

  gal_stsfree ( status ) ;
    
/*  
 * Finished.  
 */  

}

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008, 2009, 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
